@@ -113,8 +113,17 @@ def main():
         default=default_args.pop("no_epoch", False),
         help="no epoch (e.g., reinforcement learning)",
     )
+    parser.add_argument(
+        "--add-exclude",
+        nargs="+",
+        default=[],
+        help="additional exclude keys to the exclude keys in the config",
+    )
     args = parser.parse_args()
 
+    for key in args.add_exclude:
+        args.exclude.append(key)
+
     if args.version:
         print("logtable {}".format(__version__))
         sys.exit(0)
